@@ -1,3 +1,5 @@
+#' @include stopIfNotConsistent.R
+
 ## mtc.result class methods
 print.mtc.result <- function(x, ...) {
   cat("MTC ", x[['model']][['type']], " results: ", x[['model']][['description']], sep="")
@@ -9,7 +11,9 @@ summary.mtc.result <- function(object, ...) {
   scale.name <- ll.call('scale.name', object[['model']])
   rval <- list('measure'=paste0(scale.log, scale.name),
        'summaries'=summary(object[['samples']]),
-       'DIC'=unlist(object[['deviance']][c('Dbar', 'pD', 'DIC')]))
+       'DIC'=unlist(object[['deviance']][c('Dbar', 'pD', 'DIC', 'data points')]),
+       'regressor'=object[['model']][['regressor']],
+       'covariate'=object[['covariate']])
   class(rval) <- 'summary.mtc.result'
   rval
 }
@@ -17,8 +21,30 @@ summary.mtc.result <- function(object, ...) {
 print.summary.mtc.result <- function(x, ...) {
   cat(paste("\nResults on the", x[['measure']], "scale\n"))
   print(x[['summaries']])
-  cat("3. Model fit (residual deviance):\n\n")
-  print(x[['DIC']])
+  if (!is.null(x[['DIC']])) {
+    cat("-- Model fit (residual deviance):\n\n")
+    dic <- x[['DIC']]
+    print(dic[c('Dbar', 'pD', 'DIC')])
+    cat(paste0("\n", dic['data points'], " data points, ratio ",
+               format(dic['Dbar'] / dic['data points'], digits=4),
+               ", I^2 = ", format(100 * max(0, min(1, (dic['Dbar'] - dic['data points'] + 1)/dic['Dbar'])), digits=1),
+               "%\n"))
+  }
+  if (!is.null(x[['regressor']])) {
+    cat("\n-- Regression settings:\n\n")
+    r <- x[['regressor']]
+    if (!is.null(x[['regressor']][['classes']])) {
+      cat(paste0("Regression on \"", r[['variable']], "\", ", r[['coefficient']], " coefficients, by class\n"))
+    } else {
+      cat(paste0("Regression on \"", r[['variable']], "\", ", r[['coefficient']], " coefficients, \"", r[['control']], "\" as control\n"))
+    }
+    if (!is.null(x[['covariate']])) {
+      cat(paste0("Values at ", r[['variable']], " = ", x[['covariate']], "\n"))
+    } else {
+      cat(paste0("Input standardized: x' = (", r[['variable']], " - ", format(r[['center']], digits=getOption("digits")), ") / ", format(r[['scale']], digits=getOption("digits")), "\n"))
+      cat(paste0("Estimates at the centering value: ", r[['variable']], " = ", format(r[['center']], digits=getOption("digits")), "\n"))
+    }
+  }
   cat("\n")
 }
 
@@ -27,7 +53,7 @@ plot.mtc.result <- function(x, ...) {
 }
 
 forest.mtc.result <- function(x, use.description=FALSE, ...) {
-  if (tolower(x[['model']][['type']]) != 'consistency') stop("Can only apply forest.mtc.result to consistency models")
+  stopIfNotConsistent(x, "forest.mtc.result")
 
   varnames <- colnames(x[['samples']][[1]])
   samples <- as.matrix(x[['samples']][, grep("^d\\.", varnames)])
